@@ -11,7 +11,7 @@ as_vec    <- bigstatsr:::as_vec
 utils::globalVariables(c("ic", "f", "lp", "LD.wiki34", "OS", "arch", "avx2",
                          "chromosome", "position", "allele1", "allele2",
                          "myid", "marker.ID", "rsid", "chr", "pos", "p_init",
-                         "df_af"))
+                         "df_af", ".", "FREQ", "ID", "INFO", "ind_rm"))
 
 ################################################################################
 
