@@ -69,3 +69,29 @@ expect_equal(same_ref(ref1 = info_snp$a1, alt1 = info_snp$a0,
              c(TRUE, FALSE, TRUE, TRUE, TRUE))
 
 ################################################################################
+
+
+test_that("snp_asGeneticPos() works", {
+
+  info <- data.frame(
+    chr = rep(1L, 5L),
+    pos = c(853954L, 854250L, 864938L, 870645L, 873558L),
+    rsid = c("rs1806509", "rs7537756", "rs2340587", "rs28576697", "rs1110052"))
+
+  map <- data.frame(
+    V1 = c("rs1806509", "rs7537756", "rs28576697", "rs1110052"),
+    V2 = c(853954L, 854250L, 870645L, 873558L),
+    V3 = c(0.194323402834, 0.194576977815, 0.202835640491, 0.203874368612))
+  bigreadr::fwrite2(map, file.path(tempdir(), "chr1.OMNI.interpolated_genetic_map"))
+
+  res1 <- snp_asGeneticPos(info$chr, info$pos, dir = tempdir(), ncores = 2)
+  expect_equal(res1, map$V3[c(1, 2, 3, 3, 4)])
+
+  res2 <- snp_asGeneticPos(info$chr, info$pos, dir = tempdir(), ncores = 2,
+                           rsid = info$rsid)
+  expect_equal(res2[-3], map$V3)
+  expect_gt(res2[3], res2[2])
+  expect_lt(res2[3], res2[4])
+})
+
+################################################################################
